<?php 
/**
*
* search_ignore_words [Português Brasileiro]
*
* @package language
* @version 1.0.7
* @author Suporte phpBB <contato@suportephpbb.com.br> http://www.suportephpbb.com.br/
* @copyright (c) 2005 phpBB Group, 2012 Suporte phpBB
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

$words = array( 
   'abaixo',
   'acima',
   'acima de',
   'AFAIK',
   'agora',
   'agradecer',
   'ainda',
   'além',
   'além disso',
   'algum',
   'alguma coisa',
   'alguma hora',
   'algum lugar',
   'ambos',
   'ante',
   'antes',
   'apenas',
   'aqui',
   'até',
   'baixo',
   'bastante',
   'bem',
   'bom',
   'btw',
   'cada',
   'casa',
   'cima',
   'citação',
   'colocar',
   'com',
   'como',
   'como é',
   'como em',
   'como que',
   'completo',
   'cujo',
   'de',
   'de vez',
   'delas',
   'dele',
   'deles',
   'dentro',
   'depois',
   'desejar',
   'deste modo',
   'dia',
   'dias',
   'dias de',
   'disse para',
   'distância',
   'dizer',
   'e',
   'é',
   'eis',
   'ela',
   'ela está',
   'elas',
   'ele',
   'eles',
   'eles estão',
   'eles gostariam',
   'eles irão',
   'eles são',
   'eles são e estão',
   'em',
   'em volta',
   'encontrado',
   'então',
   'então é',
   'entre',
   'era',
   'escrito',
   'esses',
   'este',
   'estes',
   'etc',
   'eu',
   'eu sou',
   'eu gostaria',
   'exato',
   'existe',
   'extenso',
   'faz',
   'fez',
   'fora',
   'frequência',
   'fui',
   'gostar',
   'gostou',
   'grande',
   'href',
   'ideia',
   'ido',
   'igual',
   'IIRC',
   'incorreto',
   'indagar',
   'indo',
   'inferior',
   'ini',
   'ir',
   'irá',
   'isto',
   'isto é',
   'isto não é',
   'lá',
   'lá é',
   'largo',
   'ligar',
   'logo',
   'LOL',
   'maior parte',
   'mal',
   'maneira',
   'mas',
   'melhor',
   'melhor que',
   'menos',
   'meu',
   'muito',
   'muito de',
   'muito mais',
   'muito menos',
   'mundo',
   'nada',
   'não',
   'não é',
   'não era',
   'não faz',
   'não fez',
   'não foi',
   'não fui',
   'não irá',
   'não pôde',
   'não poder',
   'não são',
   'não tem',
   'nem',
   'nenhum',
   'no',
   'nós',
   'nosso',
   'nossos',
   'novidade',
   'novidades',
   'nunca',
   'o',
   'o qual',
   'o que',
   'obrigação',
   'observado',
   'observando',
   'olhando',
   'olhar',
   'onde',
   'oops',
   'os',
   'ou',
   'outro',
   'outro em',
   'página',
   'para',
   'pegar',
   'pequeno',
   'pequeno e',
   'pergunta',
   'perguntado',
   'perguntar',
   'perguntas',
   'perto',
   'pesquisar',
   'pior',
   'pôde',
   'poder',
   'por',
   'por em',
   'por favor',
   'porém',
   'porque',
   'porque é',
   'precisar',
   'quaisquer pessoas',
   'qualquer',
   'qualquer lugar',
   'qualquer pessoa',
   'quando',
   'quase',
   'que',
   'que é',
   'que está',
   'que gostaria',
   'quem',
   'quem é',
   'quem está',
   'realmente',
   'receber',
   'recebeu',
   'recebido',
   'recente',
   'recomendar',
   'resposta',
   'ROTF',
   'ROTFLMAO',
   'saber',
   'são',
   'se',
   'sem',
   'sem obrigação',
   'sempre',
   'ser',
   'seria',
   'seu',
   'seus',
   'sido',
   'sim',
   'sites',
   'sobre',
   'sou',
   'surgir',
   'talvez',
   'também',
   'tem',
   'tendo',
   'ter',
   'tido',
   'todos',
   'todos as',
   'todos estes',
   'todos os',
   'tudo',
   'um',
   'um tanto',
   'uma vez',
   'uno',
   'usuários',
   'utilizar',
   'vê',
   'velho',
   'ver',
   'verdade',
   'versão',
   'vez',
   'vezes',
   'visualizou',
   'viu',
   'você',
   'você é',
   'você irá',
   'você seria',
   'www', 
   'YMMV', 
); 

?>